==> haskell-loop-0.3.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-JE9GU8Sp3gFK4mFuDTRvkI
key: loop-0.3.0-JE9GU8Sp3gFK4mFuDTRvkI
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 11c4a85c4bbf9b90461b6e3d8e4ccaf6
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/loop-0.3.0
hs-libraries: HSloop-0.3.0-JE9GU8Sp3gFK4mFuDTRvkI
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-8V8WCkWAhdvHwu2gVD9TPQ
key: loop-0.3.0-8V8WCkWAhdvHwu2gVD9TPQ
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 2861757a332ca5505617436e3e9efd76
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/loop-0.3.0
hs-libraries: HSloop-0.3.0-8V8WCkWAhdvHwu2gVD9TPQ
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
